@@ -726,32 +726,40 @@ def satudata_check_similarity(string_one, string_two):
 
 
 def quality(
-        data,
-        title,
-        description,
-        tag,
-        metadata,
-        unit,
-        unit_column,
-        value_column,
-        time_series_type,
-        column_time_series,
-        category
+        data: str,
+        title: str,
+        description: str,
+        tag: list,
+        metadata: dict,
+        unit: list,
+        unit_column: str,
+        value_column: str,
+        time_series_type: str,
+        column_time_series: dict,
+        category: str,
+        code_area: dict,
+        code_area_level: str
 ):
     """
+    Data Quality Satu Data
 
-    :param data:
-    :param title:
-    :param description:
-    :param tag:
-    :param metadata:
-    :param unit:
-    :param unit_column:
-    :param value_column:
-    :param time_series_type:
-    :param column_time_series:
-    :param category:
-    :return:
+    Args:
+        data (str): dataset
+        title (str): title dataset
+        description (str): description dataset
+        tag (list): tag dataset
+        metadata (dict): metadata dataset
+        unit (list): unit dataset
+        unit_column (str): column unit dataset
+        value_column (str): column value dataset
+        time_series_type (str): time series type 'years', 'months' or 'dates'
+        column_time_series (dict): column name timeseries dataset
+        category (str): category dataset
+        code_area (dict): code area dataset
+        code_area_level (str): time series type 'province' or 'city'
+
+    Returns:
+        quality_result (dict): Data Quality Result
     """
     comformity = Comformity(
         data=data,
@@ -759,10 +767,14 @@ def quality(
         description=description,
         tag=tag,
         metadata=metadata,
-        category=category
+        category=category,
+        code_area=code_area,
+        code_area_level=code_area_level
     )
+
     comformity_quality = comformity.comformity(
-        comformity_explain_columns=40,
+        comformity_explain_columns=20,
+        comformity_code_area=20,
         comformity_measurement=20,
         comformity_serving_rate=20,
         comformity_scope=20
@@ -771,10 +783,26 @@ def quality(
     uniqueness = Uniqueness(
         data=data
     )
+
     uniqueness_quality = uniqueness.uniqueness(
         uniqeness_duplicated=100
     )
 
+    consistency = Consistency(
+        data=data,
+        unit=unit,
+        unit_column=unit_column,
+        value_column=value_column,
+        time_series_type=time_series_type,
+        column_time_series=column_time_series
+    )
+
+    consistency_quality = consistency.consistency(
+        consistency_unit=40,
+        consistency_time_series=20,
+        consistency_listing_province=40
+    )
+
     completeness = Completeness(
         data=data
     )
@@ -782,23 +810,8 @@ def quality(
         completeness_filled=100
     )
 
-    consistency = Consistency(
-        data=data,
-        unit=unit,
-        unit_column=unit_column,
-        value_column=value_column,
-        column_time_series=column_time_series,
-        time_series_type=time_series_type
-    )
-    consistency_quality = consistency.consistency(
-        consistency_unit=40,
-        consistency_separator=0,
-        consistency_value_after_comma=40,
-        consistency_time_series=20
-    )
-
     timeliness = Timeliness(
-        data,
+        data=data,
         time_series_type=time_series_type,
         column_time_series=column_time_series
     )
@@ -806,15 +819,18 @@ def quality(
         timeliness_updated=100
     )
 
-    result = (completeness_quality['completeness_result'] * 0.05) + (consistency_quality['consistency_result'] * 0.3) +\
-        (uniqueness_quality['uniqueness_result'] * 0.25) + (timeliness_quality['timeliness_result'] * 0.20) +\
-        (comformity_quality['comformity_result'] * 0.20)
-
-    quality_result = {}
-    quality_result.update(comformity_quality)
-    quality_result.update(uniqueness_quality)
-    quality_result.update(completeness_quality)
-    quality_result.update(consistency_quality)
-    quality_result.update(timeliness_quality)
-    quality_result['final_result'] = result
+    quality_result = {
+        'conformity': comformity_quality,
+        'uniqueness': uniqueness_quality,
+        'consistency': consistency_quality,
+        'completeness': completeness_quality,
+        'timeliness': timeliness_quality,
+        'final_result': (
+            (comformity_quality['result'] * 0.30)
+            + (uniqueness_quality['result'] * 0.25)
+            + (consistency_quality['result'] * 0.25)
+            + (completeness_quality['result'] * 0.10)
+            + (timeliness_quality['result'] * 0.10)
+        )
+    }
     return quality_result
